@@ -17,6 +17,42 @@ from solfege import mpd
 from solfege.mpd import mpdutils
 from solfege import cfg
 
+class TestRhythmStaff(unittest.TestCase):
+    def test_init(self):
+        rs = RhythmStaff()
+        rs.append(Bar(Rat(4, 4)))
+    def test_cmp(self):
+        r1 = RhythmStaff()
+        r1.append(Bar(Rat(4, 4)))
+        r2 = RhythmStaff()
+        r2.append(Bar(Rat(4, 4)))
+        self.assertEquals(r1, r2)
+        r2.append(Bar(Rat(4, 4)))
+        self.assertNotEquals(r1, r2)
+        r1.append(Bar(Rat(4, 4)))
+        self.assertEquals(r1, r2)
+        r1[-1].add_note(u"4")
+        self.assertNotEquals(r1, r2)
+        r2[-1].add_note(u"4")
+        self.assertNotEquals(r1, r2)
+
+class TestBar(unittest.TestCase):
+    def test1(self):
+        b = Bar(Rat(4, 4))
+        b.add_note(u"4")
+        b.add_note(u"4.")
+        b.add_rest(u"8")
+        b.add_note(u"4")
+        self.assertRaises(Bar.FullException, lambda: b.add_note(u"4"))
+    def test_err_1(self):
+        b = Bar(Rat(4, 4))
+        self.assertRaises(Bar.BadDuration, lambda: b.add_note("x"))
+        self.assertRaises(Bar.BadDuration, lambda: b.add_note("4,"))
+        self.assertRaises(Bar.BadDuration, lambda: b.add_note("."))
+        self.assertRaises(Bar.BadDuration, lambda: b.add_note("4.'"))
+        self.assertRaises(Bar.BadDuration, lambda: b.add_note(4))
+
+
 class TestParser(unittest.TestCase):
     def test_bad_musictype(self):
         s = 'question {\n' \
@@ -916,6 +952,8 @@ class TestLabelObject(unittest.TestCase):
 
 suite = unittest.makeSuite(TestParser)
 suite.addTest(unittest.makeSuite(TestMpdTransposable))
+suite.addTest(unittest.makeSuite(TestRhythmStaff))
+suite.addTest(unittest.makeSuite(TestBar))
 suite.addTest(unittest.makeSuite(TestChord))
 suite.addTest(unittest.makeSuite(TestMusic))
 suite.addTest(unittest.makeSuite(TestMusic3))
